import React, { useState, useRef, useEffect } from 'react';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { DatePicker, Select } from 'antd';
import { history } from 'umi';
import moment from 'moment';
import { Button } from 'antd'
import PageTable from '@/components/PageTable';
import { getWithdrawalList } from '@/services/withdrawal'
import { getCooperativeList } from '@/services/cooperative';

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm:ss') : '';
};
const { Option } = Select;
const goAudit = (val) => {
  history.push(`./withdrawal/audit.jsx?id=${val.withdrawalId}`);
}
const { RangePicker } = DatePicker;
export default (props) => {
  const [start, setStartDate] = useState()
  const [end, setEndDate] = useState()
  const [cooperativeList, setCooperativeList] = useState([]);
  const handelChange = (date, dateStrings) => {
    setStartDate(dateStrings[0])
    setEndDate(dateStrings[1])
  }
  const ref = useRef();
  const Reset = () => {
    setStartDate()
    setEndDate()
    ref.current.reload();
  }
  useEffect(() => {
    getCooperativeList({ pageSize: 999 }).then((res) => {
      setCooperativeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
  }, [])
  const columns = [
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      search: false,
      render: (t) => formatterTime(t),
    },
    {
      title: '合作社',
      dataIndex: 'orgId',
      key: 'orgId',
      hideInTable: true,
      renderFormItem: (item, field, form) => {
        return (
          <Select>
            {cooperativeList.map((item) => (
              <Option value={item.orgId} key={item.orgId}>
                {item.name}
              </Option>
            ))}
          </Select>
        )
      }
    },
    {
      title: '合作社',
      dataIndex: 'orgName',
      key: 'orgName',
      search: false
    },
    {
      title: '申请人',
      dataIndex: 'userName',
      key: 'userName',
    },
    {
      title: '费用',
      dataIndex: 'money',
      key: 'money',
      render: (t) => t / 100,
      search: false
    },
    //未审批  同意  不同意
    {
      title: '审批状态',
      dataIndex: 'auditStatus',
      key: 'auditStatus',
      render: (_, record) => {
        return record.auditStatus === 0 ? '未审批' :
          record.auditStatus === 1 ? '同意' : '拒绝'
      },
      valueType: 'select',
      valueEnum: {
        0: { text: '未审批' },
        1: { text: '同意' },
        2: { text: '拒绝' },
      },
    },
    //专门用来搜索
    {
      title: '申请时间',
      dataIndex: 'createDate',
      key: 'createDate',
      hideInTable: true,
      render: (t, render) => formatterTime(render.createDate),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' onChange={handelChange} />
    },
    {
      title: '审批时间',
      dataIndex: 'auditDate',
      key: 'auditDate',
      search: false,
      render: (t) => t != '-' ? formatterTime(t) : '-',
    },
    {
      title: '操作',
      valueType: 'option',
      key: 'option',
      ellipsis: true,
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => goAudit(record)}>
          详情
        </Button>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={ref}
        request={getWithdrawalList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="withdrawalId"
        options={false}
        params={{ start, end }}
        onReset={Reset}
      />
    </PageHeaderWrapper>
  );
};
