import React from 'react';
import { Table, Badge } from 'antd';
import { getMachineryList } from '@/services/machinery';
import { regeo } from '@/components/AMap/service';

export default (props) => {
  const columns = [
    {
      title: '农机',
      key: 'name',
      dataIndex: 'name',
    },
    {
      title: '状态',
      key: 'onlineStatus',
      dataIndex: 'onlineStatus',
      render: (t) =>
        t == 1 ? <Badge status="processing" text="在线" /> : <Badge status="default" text="下线" />,
    },
    {
      title: '位置',
      dataIndex: 'loc',
    },
  ];

  const [loading, setLoading] = React.useState(false);
  const [data, setData] = React.useState([]);
  const [page, setPage] = React.useState(1);

  const queryData = React.useCallback((pageNum = 1) => {
    const filter = {
      pageNum,
      pageSize: 10, // 因为高德接口限制, 一次最大只能请求 20 个地址
      isBound: true,
    };

    setLoading(true);
    getMachineryList(filter)
      .then((res) => {
        const { current, records } = res;

        setPage(current);

        const locIds = [];
        const locList = [];
        const list = records || [];

        for (let item of list) {
          if (item.onlineStatus === 1 && item.location) {
            locIds.push(item.machineryId);
            locList.push(item.location);
          }
        }

        if (locList.length > 0) {
          // 高德接口, 请求地址的描述
          regeo({ location: locList.join('|') })
            .then((regs) => {
              if (regs.status === '1') {
                regs.regeocodes.forEach((addrs, inx) => {
                  const addr = addrs['formatted_address'];
                  const machine = list.filter((x) => x.machineryId === locIds[inx])[0];
                  machine.loc = addr;
                });
              }

              setData(list);
              setPage(current);
              setLoading(false);
            })
            .catch((er) => {
              console.error(er);

              setData(list);
              setPage(current);
              setLoading(false);
            });
        }
      })
      .catch((err) => {
        console.error(err);
        setLoading(false);
      });
  }, []);

  React.useEffect(() => {
    queryData(page);
  }, [page, queryData]);

  return <Table columns={columns} dataSource={data} />;
};
