import getWeather from '@/components/AMap/weather';
// import GeoMap from '@/components/GeoMap';
import ScreenHeader from '@/components/ScreenBox/ScreenHeader';
import SquareBox from '@/components/ScreenBox/SquareBox';
import StatisCard from '@/components/ScreenBox/StatisCard';
import classNames from 'classnames';
import { useEffect, useRef, useState } from 'react';
import {
  getBasic,
  getOrgDetail,
  getTypeList,
  getAreaDetail,
  getMachineryBar,
  getWorkNumPie,
  getTypeBasic,
  getMessageList,
} from '@/services/monitoringScreen';
import MachineryStatus from './components/MachineryStatus';
import MachineryType from './components/MachineryType';
import { useParticlesJs } from './hook';
import Map from './components/map';

import ColorFont from './components/ColorFont';
import List from './components/List';
import WorkArea from './components/WorkArea';
import WorkData from './components/WorkData';
import DeviceList from './components/DeviceList';
import Styles from './style.less';

export default (props) => {
  const screenRef = useRef();
  const [weather, setWeather] = useState('暂无天气信息');

  const [basic, setBasic] = useState();

  const [machineryTypeData, setMachineryTypeData] = useState([]);

  const [machineryStatusData, setMachineryStatusData] = useState([
    { name: '预约', value: 350 },
    { name: '作业', value: 900 },
    { name: '闲置', value: 650 },
    { name: '离线', value: 180 },
    { name: '维修', value: 380 },
  ]);

  const [workData, setWorkData] = useState([]);

  const [workAreaData, setWorkAreaData] = useState([]);

  const [machineTypeList, setMachineTypeList] = useState([{ id: 't0', name: '合作社' }]);

  const [orgList, setOrgList] = useState();

  const [machineList, setMachineList] = useState([]);
  const [appointList, setAppointList] = useState();
  const [acceptList, setAcceptList] = useState();

  useEffect(() => {
    //顶部基本数据
    getBasic()
      .then((res) => {
        var data = {};
        for (let i = 0; i < res.length; i++) {
          const element = res[i];
          data[element.name] = element.value;
        }
        setBasic(data);
      })
      .catch((err) => {
        console.log(err.message);
      });
    //地图上合作社的marker
    getOrgDetail()
      .then((res) => {
        res.forEach((item) => {
          item.lnglat = [item['lng'] - 0, item['lat'] - 0];
          item.machineryNum = item.machineryNum - 0;
        });
        setOrgList(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
    //获取地图上所有农机markers
    getTypeBasic()
      .then((res) => {
        res.forEach((item) => {
          item.lnglat = [item.location.split(',')[0] - 0, item.location.split(',')[1] - 0];
        });
        setMachineList(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
    //获取地图左侧选择的农机列表
    getTypeList()
      .then((res) => {
        let data = [].concat(machineTypeList);
        res.forEach((item) => {
          data.push({ id: item.typeId, name: item.name });
        });
        setMachineTypeList(data);
      })
      .catch((err) => {
        console.log(err.message);
      });
    //作业面积统计
    getAreaDetail()
      .then((res) => {
        setWorkAreaData([].concat(res));
      })
      .catch((err) => {
        console.log(err.message);
      });
    //农机类型统计
    getMachineryBar()
      .then((res) => {
        setMachineryTypeData(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
    //农机作业数统计
    getWorkNumPie()
      .then((res) => {
        setWorkData(res);
      })
      .catch((err) => {
        console.log(err.message);
      });

    getMessageList({ messageType: 'appoint' })
      .then((res) => {
        setAppointList(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
    getMessageList({ messageType: 'accept' })
      .then((res) => {
        setAcceptList(res);
      })
      .catch((err) => {
        console.log(err.message);
      });

    getWeather()
      .then((res) => {
        if (res && res.length) {
          const { casts, city } = res[0];
          const { dayweather, nighttemp, daytemp } = casts[0];
          const [min, max] =
            parseInt(nighttemp) > parseInt(daytemp) ? [daytemp, nighttemp] : [nighttemp, daytemp];
          setWeather(`${city} ${dayweather} ${min}-${max} °C`);
        } else {
          setWeather('暂无天气信息');
        }
      })
      .catch((err) => {
        console.log(err.message);
      });
  }, []);

  useParticlesJs(Styles['particles-js']);

  return (
    <div className={classNames(Styles['screen-page'], Styles['pd-lr-40'])} ref={screenRef}>
      <div id={Styles['particles-js']} />
      <div className={Styles['grail-layout']}>
        <div className={Styles['grail-header']}>
          <ScreenHeader weather={weather} />
        </div>
        <div className={classNames(Styles['grail-container'], Styles['mg-tp-30'])}>
          <div className={classNames(Styles['grail-content'], Styles['pd-lr-40'])}>
            <div className={Styles['statis-container']}>
              <StatisCard
                color="#23E8AE"
                icon="icon1"
                value={basic?.totalMachineryNum}
                title="农机总数（台）"
              />
              <StatisCard
                color="#0BDAFF"
                icon="icon2"
                value={basic?.totalMachineryUsed}
                title="农机使用数（台）"
              />
              <StatisCard
                color="#F5CC5C"
                icon="icon3"
                value={basic?.totalOrderNum}
                title="总预约数"
              />
              <StatisCard
                color="#C579FF"
                icon="icon4"
                value={basic?.totalServiceNum}
                title="总服务数"
              />
            </div>
            {/* <GeoMap machineTypeList={machineTypeList} orgList={orgList} machineList={machineList} /> */}
            <Map />
          </div>
        </div>
        <div>
          <DeviceList />
        </div>
      </div>
    </div>
  );
};
